From 0c705cbc938a5d70989cec02e5625cdbeda6959e Mon Sep 17 00:00:00 2001
From: Paul Selkirk <paul@psgd.org>
Date: Thu, 16 Aug 2018 17:40:44 -0400
Subject: Correct the limit on memory banks in the keywrap core.

---
 aes_keywrap.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/aes_keywrap.c b/aes_keywrap.c
index 77146e6..8ef018b 100644
--- a/aes_keywrap.c
+++ b/aes_keywrap.c
@@ -144,8 +144,8 @@ static hal_error_t do_keywrap_core(const hal_core_t *core, uint8_t * const C, co
 
   hal_assert(core != NULL && C != NULL && n > 0);
 
-  /* The core is currently limited to 4 banks of 512 bytes, which is way too small. */
-  if (n == 0 || n > 4 * 64)
+  /* The core is limited to 128 banks of 512 bytes/64 blocks */
+  if (n == 0 || n > 128 * 64)
     return HAL_ERROR_BAD_ARGUMENTS;
 
   /* write the AIV to A */
-- 
cgit v1.2.3